<?php declare(strict_types=1);

use BitBadger\PDODocument\{Configuration, Definition, Mode};
use Dotenv\Dotenv;
use MyPrayerJournal\{Auth, Layout, Table};

require __DIR__ . '/vendor/autoload.php';

/** The version of this application */
const MPJ_VERSION = '4.0.0-alpha1';

(Dotenv::createImmutable(__DIR__))->load();

if (php_sapi_name() != 'cli') {
    session_start();

    $auth0_user = Auth::user();
    if (!is_null($auth0_user)) {
        $_SESSION['user_id'] = $auth0_user['sub'];
    }

    $_REQUEST['time_zone'] = $_SERVER['HTTP_X_TIME_ZONE'] ?? 'Etc/UTC';
}

Configuration::$pdoDSN = 'sqlite:' . implode(DIRECTORY_SEPARATOR, [__DIR__, 'data', 'mpj.db']);
Configuration::$mode   = Mode::SQLite;
Definition::ensureTable(Table::REQUEST);

$_PATCH = [];
if ($_SERVER['REQUEST_METHOD'] ?? '' == 'PATCH') parse_str(file_get_contents('php://input'), $_PATCH);

/**
 * Return a 404 and exit
 */
function not_found(): never
{
    http_response_code(404);
    die('Not found');
}

/**
 * Return a 303 redirect ("see other" - redirects to a GET)
 *
 * @param string $url The URL to which the browser should be redirected
 */
function see_other(string $url): never
{
    header('Location: ' . (str_starts_with($url, 'http') ? '/' : $url));
    http_response_code(303);
    exit;
}

/**
 * Add a header that instructs the browser to close an open modal dialog
 *
 * @param string $name The name of the dialog to be closed
 */
function hide_modal(string $name): void
{
    header("X-Hide-Modal: $name");
}
